@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP              #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE LambdaCase       #-}
 {-# LANGUAGE TupleSections    #-}
@@ -8,12 +9,16 @@ import           Control.Concurrent  (threadDelay)
 import           Control.Monad       (forM, forM_, mplus, unless, void)
 import           Control.Monad.State (get, gets, lift, liftIO, put, runStateT)
 import           Data.Bifunctor      (bimap)
-import           Data.Foldable       (foldl')
 import           Data.Function       (on)
 import           Data.List           (intersperse, minimumBy)
 import           Data.Maybe          (fromMaybe, isJust, isNothing, maybeToList)
 import           Safe                (atMay)
 
+#if !MIN_VERSION_base(4,20,0)
+-- foldl' started being exported from prelude in base-4.20.0
+import           Data.Foldable       (foldl')
+#endif
+
 import qualified Data.Map.Strict     as M
 import qualified Data.Set            as S
 
@@ -502,7 +507,10 @@ drawMainScreen game = do
             , let lev = HS.maxLevel hs in (showLevel lev, levelStyle lev)
             ] <>
             [ ("  ", style0) ] <>
-            [ (take 1 $ show e, equipStyle e) | e <- S.toList $ HS.equipment hs ]
+            [ if e `elem` HS.equipment hs
+                then (take 1 $ show e, equipStyle e)
+                else ("-", style0)
+            | e <- allEquipment ]
         scoreX showName = min ((scrW - l) `div` 2) (scrW - l - 1 - aKeyL)
             where l = sum $ [length "99   99~  99:C"]
                     <> [11 | showName] <> [2 + length allEquipment]
